@@ -30,7 +30,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 %EXPORT_TAGS = (DEFAULT => [qw(&user_sign_is_valid &calc_pub_key_id &encrypt &send_doc &get_docs &split_base64)]);
 
 BEGIN {
-  $VERSION = '0.3';
+  $VERSION = '0.4';
 }
 
 =head1 NAME
@@ -212,15 +212,18 @@ sub encrypt {
     # Первые 256 байт - зашифрованный 256-битный AES ключ
     # Дальше - данные зашифрованные AES с помощью этого ключа
     my $enc_data = '';
-    
+
+    # Случайный ключ AES (256 bit)
     my $aes_key = random_bytes(32);
-    $enc_data .= $rsa->encrypt($aes_key);
+    # Случайный вектор инициализации IV (
+    my $aes_iv = random_bytes(16);
+    $enc_data .= $rsa->encrypt($aes_key.$aes_iv);
 
     my $aes_cbc = Crypt::CBC->new( -key => $aes_key,
                                     -literal_key => 1,
                                     -keysize => 32,
                                     -cipher => "Crypt::OpenSSL::AES",
-                                    -iv => '7350264181172691',
+                                    -iv => $aes_iv,
                                     -header => 'none' );
     
     $enc_data .= $aes_cbc->encrypt($data);
